@@ -6,7 +6,7 @@ set.seed(1234)
 context("ROSE")
 
 test_that("minority_prop value", {
-  rec <- recipe(~ ., data = circle_example)
+  rec <- recipe(~., data = circle_example)
   rec21 <- rec %>%
     step_rose(class, minority_prop = 0.1)
 
@@ -16,8 +16,8 @@ test_that("minority_prop value", {
   rec21_p <- prep(rec21, training = circle_example)
   rec22_p <- prep(rec22, training = circle_example)
 
-  tr_xtab1 <- table(juice(rec21_p)$class, useNA = "no")
-  tr_xtab2 <- table(juice(rec22_p)$class, useNA = "no")
+  tr_xtab1 <- table(bake(rec21_p, new_data = NULL)$class, useNA = "no")
+  tr_xtab2 <- table(bake(rec22_p, new_data = NULL)$class, useNA = "no")
 
   expect_equal(sum(tr_xtab1), sum(tr_xtab2))
 
@@ -26,7 +26,7 @@ test_that("minority_prop value", {
 
 test_that("tunable", {
   rec <-
-    recipe(~ ., data = iris) %>%
+    recipe(~., data = iris) %>%
     step_rose(all_predictors(), under_ratio = 1)
   rec_param <- tunable.step_rose(rec$steps[[1]])
   expect_equal(rec_param$name, c("over_ratio"))
