@@ -6,11 +6,15 @@ test_that("samples stay inside convex hull of data.", {
 })
 
 test_that("order doesn't matter", {
-  df <- data.frame(target = rep(c("Yes", "No"), c(10, 50)),
-                   x = rep(1:2, c(10, 50)))
+  df <- data.frame(
+    target = rep(c("Yes", "No"), c(10, 50)),
+    x = rep(1:2, c(10, 50))
+  )
   expect_equal(100, nrow(themis:::smote(df, "target")))
 
-  df <- data.frame(target = rep(c("Yes", "No"), c(50, 10)),
-                   x = rep(1:2, c(50, 10)))
+  df <- data.frame(
+    target = rep(c("Yes", "No"), c(50, 10)),
+    x = rep(1:2, c(50, 10))
+  )
   expect_equal(100, nrow(themis:::smote(df, "target")))
 })
